pub struct Image { /* private fields */ }Implementations
Sourceimpl Image
impl Image
Sourcepub fn new(width: u32, height: u32, image: Vec<bool>) -> Result<Image, String>
pub fn new(width: u32, height: u32, image: Vec<bool>) -> Result<Image, String>
Requires the width and height of the image in terms of pixels The height has no max while the width is limited to constant:MAX_X_WIDTH which is 1024 The vector contains pixels from top left to bottom right in a left to right fashion